SystemOrganization addCategory: #SimpleContactManager!
SystemOrganization addCategory: #'SimpleContactManager-Core'!
SystemOrganization addCategory: #'SimpleContactManager-Core-Tests'!

TestCase subclass: #ContactBookTest
	instanceVariableNames: 'defaultBook'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'SimpleContactManager-Core-Tests'!

!ContactBookTest methodsFor: 'running' stamp: 'PeterPesch 6/29/2020 15:27'!
setUp
	"Hooks that subclasses may override to define the fixture of test."
	super setUp.
	defaultBook := ContactBook createDefault
! !

!ContactBookTest methodsFor: 'tests' stamp: 'PeterPesch 6/29/2020 15:28'!
testAddContact
	| contact before after |
	contact := Contact newNamed: 'Jan' email: 'abc@def.ghi'.
	before := defaultBook contacts size.
	defaultBook addContact: contact.
	after := defaultBook contacts size.
	defaultBook removeContact: contact.
	self assert: after equals: before + 1.
	! !

!ContactBookTest methodsFor: 'tests' stamp: 'PeterPesch 6/29/2020 15:29'!
testRemoveContact
	| contact before after |
	contact := Contact newNamed: 'Jan' email: 'abc@def.ghi'.
	before := defaultBook contacts size.
	defaultBook addContact: contact.
	after := defaultBook contacts size.
	defaultBook removeContact: contact.
	self assert: after equals: before + 1.
	! !

TestCase subclass: #ContactTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'SimpleContactManager-Core-Tests'!

!ContactTest methodsFor: 'tests' stamp: 'PeterPesch 6/29/2020 15:00'!
testCreation
	| contact |
	contact := Contact
		newNamed: 'Marcus Denker'
		email: 'marcus.denker@inria.fr'.
	self assert: contact fullname equals: 'Marcus Denker'.
	self assert: contact email equals: 'marcus.denker@inria.fr'.! !

Object subclass: #Contact
	instanceVariableNames: 'fullname email'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'SimpleContactManager-Core'!

!Contact commentStamp: 'PeterPesch 6/29/2020 15:11' prior: 0!
I represent a person within the contact book application.

For the Responsibility part: Three sentences about my main responsibilities - what I do, what I know.

For the Collaborators Part: State my main collaborators and one line about how I interact with them. 

Public API and Key Messages

- message one   
- message two 
- (for bonus points) how to create instances.

   One simple example is simply gorgeous.
 
Internal Representation and Key Implementation Points.

    Instance Variables
	email:		<Object>
	fullname:		<Object>


    Implementation Points!

!Contact class methodsFor: 'instance creation' stamp: 'PeterPesch 6/29/2020 14:57'!
newNamed: aNameString email: anEmailString
	^ self new
	fullname: aNameString;
	email: anEmailString;
	yourself! !

!Contact methodsFor: 'accessing' stamp: 'PeterPesch 6/29/2020 14:58'!
email
	^ email! !

!Contact methodsFor: 'accessing' stamp: 'PeterPesch 6/29/2020 14:58'!
email: aString
	email := aString! !

!Contact methodsFor: 'accessing' stamp: 'PeterPesch 6/29/2020 14:58'!
fullname
	^ fullname! !

!Contact methodsFor: 'accessing' stamp: 'PeterPesch 6/29/2020 14:58'!
fullname: aString
	fullname := aString! !

!Contact methodsFor: 'printing' stamp: 'PeterPesch 6/29/2020 15:08'!
printOn: aStream
	aStream
		nextPutAll: self fullname;
		nextPutAll: ' <';
		nextPutAll: self email;
		nextPutAll: '>'! !

Object subclass: #ContactBook
	instanceVariableNames: 'contacts'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'SimpleContactManager-Core'!

!ContactBook commentStamp: 'PeterPesch 6/29/2020 15:10' prior: 0!
I am a simple contact book application with a web interface.

For the Responsibility part: Three sentences about my main responsibilities - what I do, what I know.

For the Collaborators Part: State my main collaborators and one line about how I interact with them. 

Public API and Key Messages

- message one   
- message two 
- (for bonus points) how to create instances.

   One simple example is simply gorgeous.
 
Internal Representation and Key Implementation Points.

    Instance Variables
	contacts:		<Object>


    Implementation Points!

!ContactBook class methodsFor: 'current' stamp: 'PeterPesch 6/29/2020 15:18'!
createDefault
	^ self new
	addContact: (Contact
		newNamed: 'Damien Cassou'
		email: 'damien@cassou.me');
	addContact: (Contact
		newNamed: 'Marcus Denker'
		email: 'marcus.denker@inria.fr');
	addContact: (Contact
		newNamed: 'Tudor Girba'
		email: 'tudor@tudorgirba.com');
	addContact: (Contact
		newNamed: 'Clara Allende'
		email: 'clari.allende@gmail.com');
	yourself! !

!ContactBook methodsFor: 'action' stamp: 'PeterPesch 6/29/2020 15:12'!
addContact: aContact
	self contacts add: aContact! !

!ContactBook methodsFor: 'accessing' stamp: 'PeterPesch 6/29/2020 15:12'!
contacts
	^ contacts ifNil: [ contacts := OrderedCollection new ]! !

!ContactBook methodsFor: 'action' stamp: 'PeterPesch 6/29/2020 15:12'!
removeContact: aContact
	self contacts remove: aContact! !
